#include "obj_pstk.h"

#define GVT_DONT_UNDEF
#include "vtpadstack.h"
#include <genvector/genvector_impl.c>

